@@ -28,6 +28,12 @@ def cli(username: str, password: str, url: str = None):
         context.client.set_credentials(username, password)
 
 
+@cli.command
+def get_package_root_folder():
+    """Get root folder of package located in current folder"""
+    print(get_setup_metadata("packages")[0])
+
+
 @cli.group()
 def setup_meta():
     """Commands related to reliably parsing setup.py"""
@@ -40,6 +46,7 @@ def get(metadata_name: str):
     print(get_setup_metadata(metadata_name))
 
 
+
 @cli.group
 def package():
     """Manage packages"""
